.. _creating_planetary_wcs:

Creating a planetary WCS structure
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

To create a WCS planetary object, a planetary frame needs to be defined,
with a planetary body representation (see :ref:`astropy-coordinates-representations`
for more about representations)

.. literalinclude:: examples/planetary_wcs.py
   :language: python
